@@ -31,7 +31,7 @@ class EdfReader(CyEdfReader):
     def __enter__(self):
         return self
 
-    def __del_(self):
+    def __del__(self):
         self._close()
 
     def __exit__(self, exc_type, exc_val, ex_tb):
@@ -333,7 +333,7 @@ class EdfReader(CyEdfReader):
         return datetime(self.startdate_year, self.startdate_month, self.startdate_day,
                                  self.starttime_hour, self.starttime_minute, self.starttime_second)
 
-    def getBirthdate(self):
+    def getBirthdate(self, string=True):
         """
         Returns the birthdate as string object
 
@@ -351,7 +351,11 @@ class EdfReader(CyEdfReader):
         >>> del f
 
         """
-        return self._convert_string(self.birthdate.rstrip())
+
+        if string:
+            return self._convert_string(self.birthdate.rstrip())
+        else:
+            return datetime.strptime(self._convert_string(self.birthdate.rstrip()), "%d %b %Y")
 
     def getSampleFrequencies(self):
         """
@@ -683,8 +687,11 @@ class EdfReader(CyEdfReader):
         print("signals in file:", self.signals_in_file)
 
     def file_info_long(self):
+        """
+        Returns information about the opened EDF/BDF file
+        """
         self.file_info()
         for ii in np.arange(self.signals_in_file):
-            print("label:", self.getSignalLabel(ii), "fs:",
-                  self.getSignalFreqs()[ii], "nsamples",
+            print("label:", self.getSignalLabels()[ii], "fs:",
+                  self.getSampleFrequencies()[ii], "nsamples",
                   self.getNSamples()[ii])
